Class: Aws::ManagedBlockchain::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ManagedBlockchain::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-managedblockchain/client.rb,
sig/client.rbs
Overview
An API client for ManagedBlockchain. To construct a client, you need to configure a :region and :credentials.
client = Aws::ManagedBlockchain::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAccessorResponseSuccess, _CreateMemberResponseSuccess, _CreateNetworkResponseSuccess, _CreateNodeResponseSuccess, _CreateProposalResponseSuccess, _DeleteAccessorResponseSuccess, _DeleteMemberResponseSuccess, _DeleteNodeResponseSuccess, _GetAccessorResponseSuccess, _GetMemberResponseSuccess, _GetNetworkResponseSuccess, _GetNodeResponseSuccess, _GetProposalResponseSuccess, _ListAccessorsResponseSuccess, _ListInvitationsResponseSuccess, _ListMembersResponseSuccess, _ListNetworksResponseSuccess, _ListNodesResponseSuccess, _ListProposalVotesResponseSuccess, _ListProposalsResponseSuccess, _ListTagsForResourceResponseSuccess, _RejectInvitationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateMemberResponseSuccess, _UpdateNodeResponseSuccess, _VoteOnProposalResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_accessor(params = {}) ⇒ Types::CreateAccessorOutput
Creates a new accessor for use with Amazon Managed Blockchain service that supports token based access.
-
#create_member(params = {}) ⇒ Types::CreateMemberOutput
Creates a member within a Managed Blockchain network.
-
#create_network(params = {}) ⇒ Types::CreateNetworkOutput
Creates a new blockchain network using Amazon Managed Blockchain.
-
#create_node(params = {}) ⇒ Types::CreateNodeOutput
Creates a node on the specified blockchain network.
-
#create_proposal(params = {}) ⇒ Types::CreateProposalOutput
Creates a proposal for a change to the network that other members of the network can vote on, for example, a proposal to add a new member to the network.
-
#delete_accessor(params = {}) ⇒ Struct
Deletes an accessor that your Amazon Web Services account owns.
-
#delete_member(params = {}) ⇒ Struct
Deletes a member.
-
#delete_node(params = {}) ⇒ Struct
Deletes a node that your Amazon Web Services account owns.
-
#get_accessor(params = {}) ⇒ Types::GetAccessorOutput
Returns detailed information about an accessor.
-
#get_member(params = {}) ⇒ Types::GetMemberOutput
Returns detailed information about a member.
-
#get_network(params = {}) ⇒ Types::GetNetworkOutput
Returns detailed information about a network.
-
#get_node(params = {}) ⇒ Types::GetNodeOutput
Returns detailed information about a node.
-
#get_proposal(params = {}) ⇒ Types::GetProposalOutput
Returns detailed information about a proposal.
-
#list_accessors(params = {}) ⇒ Types::ListAccessorsOutput
Returns a list of the accessors and their properties.
-
#list_invitations(params = {}) ⇒ Types::ListInvitationsOutput
Returns a list of all invitations for the current Amazon Web Services account.
-
#list_members(params = {}) ⇒ Types::ListMembersOutput
Returns a list of the members in a network and properties of their configurations.
-
#list_networks(params = {}) ⇒ Types::ListNetworksOutput
Returns information about the networks in which the current Amazon Web Services account participates.
-
#list_nodes(params = {}) ⇒ Types::ListNodesOutput
Returns information about the nodes within a network.
-
#list_proposal_votes(params = {}) ⇒ Types::ListProposalVotesOutput
Returns the list of votes for a specified proposal, including the value of each vote and the unique identifier of the member that cast the vote.
-
#list_proposals(params = {}) ⇒ Types::ListProposalsOutput
Returns a list of proposals for the network.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for the specified resource.
-
#reject_invitation(params = {}) ⇒ Struct
Rejects an invitation to join a network.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites the specified tags for the specified Amazon Managed Blockchain resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the Amazon Managed Blockchain resource.
-
#update_member(params = {}) ⇒ Struct
Updates a member configuration with new parameters.
-
#update_node(params = {}) ⇒ Struct
Updates a node configuration with new parameters.
-
#vote_on_proposal(params = {}) ⇒ Struct
Casts a vote for a specified
ProposalIdon behalf of a member.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2028 2029 2030 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 2028 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2031 2032 2033 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 2031 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 2001 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ManagedBlockchain') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-managedblockchain' context[:gem_version] = '1.88.0' Seahorse::Client::Request.new(handlers, context) end |
#create_accessor(params = {}) ⇒ Types::CreateAccessorOutput
Creates a new accessor for use with Amazon Managed Blockchain service that supports token based access. The accessor contains information required for token based access.
88 |
# File 'sig/client.rbs', line 88
def create_accessor: (
|
#create_member(params = {}) ⇒ Types::CreateMemberOutput
Creates a member within a Managed Blockchain network.
Applies only to Hyperledger Fabric.
101 |
# File 'sig/client.rbs', line 101
def create_member: (
|
#create_network(params = {}) ⇒ Types::CreateNetworkOutput
Creates a new blockchain network using Amazon Managed Blockchain.
Applies only to Hyperledger Fabric.
115 |
# File 'sig/client.rbs', line 115
def create_network: (
|
#create_node(params = {}) ⇒ Types::CreateNodeOutput
Creates a node on the specified blockchain network.
Applies to Hyperledger Fabric and Ethereum.
143 |
# File 'sig/client.rbs', line 143
def create_node: (
|
#create_proposal(params = {}) ⇒ Types::CreateProposalOutput
Creates a proposal for a change to the network that other members of the network can vote on, for example, a proposal to add a new member to the network. Any member can create a proposal.
Applies only to Hyperledger Fabric.
162 |
# File 'sig/client.rbs', line 162
def create_proposal: (
|
#delete_accessor(params = {}) ⇒ Struct
Deletes an accessor that your Amazon Web Services account owns. An
accessor object is a container that has the information required for
token based access to your Ethereum nodes including, the
BILLING_TOKEN. After an accessor is deleted, the status of the
accessor changes from AVAILABLE to PENDING_DELETION. An accessor
in the PENDING_DELETION state can’t be used for new WebSocket
requests or HTTP requests. However, WebSocket connections that were
initiated while the accessor was in the AVAILABLE state remain open
until they expire (up to 2 hours).
187 |
# File 'sig/client.rbs', line 187
def delete_accessor: (
|
#delete_member(params = {}) ⇒ Struct
Deletes a member. Deleting a member removes the member and all
associated resources from the network. DeleteMember can only be
called for a specified MemberId if the principal performing the
action is associated with the Amazon Web Services account that owns
the member. In all other cases, the DeleteMember action is carried
out as the result of an approved proposal to remove a member. If
MemberId is the last member in a network specified by the last
Amazon Web Services account, the network is deleted also.
Applies only to Hyperledger Fabric.
196 |
# File 'sig/client.rbs', line 196
def delete_member: (
|
#delete_node(params = {}) ⇒ Struct
Deletes a node that your Amazon Web Services account owns. All data on the node is lost and cannot be recovered.
Applies to Hyperledger Fabric and Ethereum.
206 |
# File 'sig/client.rbs', line 206
def delete_node: (
|
#get_accessor(params = {}) ⇒ Types::GetAccessorOutput
Returns detailed information about an accessor. An accessor object is a container that has the information required for token based access to your Ethereum nodes.
218 |
# File 'sig/client.rbs', line 218
def get_accessor: (
|
#get_member(params = {}) ⇒ Types::GetMemberOutput
Returns detailed information about a member.
Applies only to Hyperledger Fabric.
228 |
# File 'sig/client.rbs', line 228
def get_member: (
|
#get_network(params = {}) ⇒ Types::GetNetworkOutput
Returns detailed information about a network.
Applies to Hyperledger Fabric and Ethereum.
239 |
# File 'sig/client.rbs', line 239
def get_network: (
|
#get_node(params = {}) ⇒ Types::GetNodeOutput
Returns detailed information about a node.
Applies to Hyperledger Fabric and Ethereum.
249 |
# File 'sig/client.rbs', line 249
def get_node: (
|
#get_proposal(params = {}) ⇒ Types::GetProposalOutput
Returns detailed information about a proposal.
Applies only to Hyperledger Fabric.
261 |
# File 'sig/client.rbs', line 261
def get_proposal: (
|
#list_accessors(params = {}) ⇒ Types::ListAccessorsOutput
Returns a list of the accessors and their properties. Accessor objects are containers that have the information required for token based access to your Ethereum nodes.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
273 |
# File 'sig/client.rbs', line 273
def list_accessors: (
|
#list_invitations(params = {}) ⇒ Types::ListInvitationsOutput
Returns a list of all invitations for the current Amazon Web Services account.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
286 |
# File 'sig/client.rbs', line 286
def list_invitations: (
|
#list_members(params = {}) ⇒ Types::ListMembersOutput
Returns a list of the members in a network and properties of their configurations.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
298 |
# File 'sig/client.rbs', line 298
def list_members: (
|
#list_networks(params = {}) ⇒ Types::ListNetworksOutput
Returns information about the networks in which the current Amazon Web Services account participates.
Applies to Hyperledger Fabric and Ethereum.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
314 |
# File 'sig/client.rbs', line 314
def list_networks: (
|
#list_nodes(params = {}) ⇒ Types::ListNodesOutput
Returns information about the nodes within a network.
Applies to Hyperledger Fabric and Ethereum.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
329 |
# File 'sig/client.rbs', line 329
def list_nodes: (
|
#list_proposal_votes(params = {}) ⇒ Types::ListProposalVotesOutput
Returns the list of votes for a specified proposal, including the value of each vote and the unique identifier of the member that cast the vote.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
344 |
# File 'sig/client.rbs', line 344
def list_proposal_votes: (
|
#list_proposals(params = {}) ⇒ Types::ListProposalsOutput
Returns a list of proposals for the network.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
358 |
# File 'sig/client.rbs', line 358
def list_proposals: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for the specified resource. Each tag consists of a key and optional value.
For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide.
370 |
# File 'sig/client.rbs', line 370
def list_tags_for_resource: (
|
#reject_invitation(params = {}) ⇒ Struct
Rejects an invitation to join a network. This action can be called by a principal in an Amazon Web Services account that has received an invitation to create a member and join a network.
Applies only to Hyperledger Fabric.
379 |
# File 'sig/client.rbs', line 379
def reject_invitation: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites the specified tags for the specified Amazon Managed Blockchain resource. Each tag consists of a key and optional value.
When you specify a tag key that already exists, the tag value is
overwritten with the new value. Use UntagResource to remove tag
keys.
A resource can have up to 50 tags. If you try to create more than 50 tags for a resource, your request fails and returns an error.
For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide.
388 |
# File 'sig/client.rbs', line 388
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the Amazon Managed Blockchain resource.
For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide.
398 |
# File 'sig/client.rbs', line 398
def untag_resource: (
|
#update_member(params = {}) ⇒ Struct
Updates a member configuration with new parameters.
Applies only to Hyperledger Fabric.
408 |
# File 'sig/client.rbs', line 408
def update_member: (
|
#update_node(params = {}) ⇒ Struct
Updates a node configuration with new parameters.
Applies only to Hyperledger Fabric.
419 |
# File 'sig/client.rbs', line 419
def update_node: (
|
#vote_on_proposal(params = {}) ⇒ Struct
Casts a vote for a specified ProposalId on behalf of a member. The
member to vote as, specified by VoterMemberId, must be in the same
Amazon Web Services account as the principal that calls the action.
Applies only to Hyperledger Fabric.
431 |
# File 'sig/client.rbs', line 431
def vote_on_proposal: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2021 2022 2023 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 2021 def waiter_names [] end |