Class: Aws::ManagedBlockchain::Types::CreateAccessorOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-managedblockchain/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accessor_idString

The unique identifier of the accessor.



271
272
273
274
275
276
277
# File 'lib/aws-sdk-managedblockchain/types.rb', line 271

class CreateAccessorOutput < Struct.new(
  :accessor_id,
  :billing_token,
  :network_type)
  SENSITIVE = []
  include Aws::Structure
end

#billing_tokenString

The billing token is a property of the Accessor. Use this token to when making calls to the blockchain network. The billing token is used to track your accessor token for billing requests.



271
272
273
274
275
276
277
# File 'lib/aws-sdk-managedblockchain/types.rb', line 271

class CreateAccessorOutput < Struct.new(
  :accessor_id,
  :billing_token,
  :network_type)
  SENSITIVE = []
  include Aws::Structure
end

#network_typeString

The blockchain network that the accessor token is created for.



271
272
273
274
275
276
277
# File 'lib/aws-sdk-managedblockchain/types.rb', line 271

class CreateAccessorOutput < Struct.new(
  :accessor_id,
  :billing_token,
  :network_type)
  SENSITIVE = []
  include Aws::Structure
end