Class: Aws::ManagedBlockchain::Types::ListMembersInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-managedblockchain/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_owned ⇒ Boolean

An optional Boolean value. If provided, the request is limited either to members that the current Amazon Web Services account owns (true) or that other Amazon Web Services accountsn own (false). If omitted, all members are listed.

Returns:

  • (Boolean)


1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1019

class ListMembersInput < Struct.new(
  :network_id,
  :name,
  :status,
  :is_owned,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of members to return in the request.

Returns:

  • (Integer)


1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1019

class ListMembersInput < Struct.new(
  :network_id,
  :name,
  :status,
  :is_owned,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The optional name of the member to list.

Returns:

  • (String)


1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1019

class ListMembersInput < Struct.new(
  :network_id,
  :name,
  :status,
  :is_owned,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_id ⇒ String

The unique identifier of the network for which to list members.

Returns:

  • (String)


1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1019

class ListMembersInput < Struct.new(
  :network_id,
  :name,
  :status,
  :is_owned,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token that indicates the next set of results to retrieve.

Returns:

  • (String)


1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1019

class ListMembersInput < Struct.new(
  :network_id,
  :name,
  :status,
  :is_owned,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

An optional status specifier. If provided, only members currently in this status are listed.

Returns:

  • (String)


1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1019

class ListMembersInput < Struct.new(
  :network_id,
  :name,
  :status,
  :is_owned,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end