Class: Aws::ManagedBlockchain::Types::NetworkSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-managedblockchain/types.rb

Overview

A summary of network configuration properties.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the network. For more information about ARNs and their format, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1949

class NetworkSummary < Struct.new(
  :id,
  :name,
  :description,
  :framework,
  :framework_version,
  :status,
  :creation_date,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date ⇒ Time

The date and time that the network was created.

Returns:

  • (Time)


1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1949

class NetworkSummary < Struct.new(
  :id,
  :name,
  :description,
  :framework,
  :framework_version,
  :status,
  :creation_date,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

An optional description of the network.

Returns:

  • (String)


1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1949

class NetworkSummary < Struct.new(
  :id,
  :name,
  :description,
  :framework,
  :framework_version,
  :status,
  :creation_date,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#framework ⇒ String

The blockchain framework that the network uses.

Returns:

  • (String)


1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1949

class NetworkSummary < Struct.new(
  :id,
  :name,
  :description,
  :framework,
  :framework_version,
  :status,
  :creation_date,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#framework_version ⇒ String

The version of the blockchain framework that the network uses.

Returns:

  • (String)


1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1949

class NetworkSummary < Struct.new(
  :id,
  :name,
  :description,
  :framework,
  :framework_version,
  :status,
  :creation_date,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The unique identifier of the network.

Returns:

  • (String)


1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1949

class NetworkSummary < Struct.new(
  :id,
  :name,
  :description,
  :framework,
  :framework_version,
  :status,
  :creation_date,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the network.

Returns:

  • (String)


1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1949

class NetworkSummary < Struct.new(
  :id,
  :name,
  :description,
  :framework,
  :framework_version,
  :status,
  :creation_date,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the network.

Returns:

  • (String)


1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
# File 'lib/aws-sdk-managedblockchain/types.rb', line 1949

class NetworkSummary < Struct.new(
  :id,
  :name,
  :description,
  :framework,
  :framework_version,
  :status,
  :creation_date,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end