Class: Aws::ManagedBlockchain::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ManagedBlockchain::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-managedblockchain/client.rb
Overview
An API client for ManagedBlockchain. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ManagedBlockchain::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_accessor(params = {}) ⇒ Types::CreateAccessorOutput
Creates a new accessor for use with Amazon Managed Blockchain service that supports token based access.
-
#create_member(params = {}) ⇒ Types::CreateMemberOutput
Creates a member within a Managed Blockchain network.
-
#create_network(params = {}) ⇒ Types::CreateNetworkOutput
Creates a new blockchain network using Amazon Managed Blockchain.
-
#create_node(params = {}) ⇒ Types::CreateNodeOutput
Creates a node on the specified blockchain network.
-
#create_proposal(params = {}) ⇒ Types::CreateProposalOutput
Creates a proposal for a change to the network that other members of the network can vote on, for example, a proposal to add a new member to the network.
-
#delete_accessor(params = {}) ⇒ Struct
Deletes an accessor that your Amazon Web Services account owns.
-
#delete_member(params = {}) ⇒ Struct
Deletes a member.
-
#delete_node(params = {}) ⇒ Struct
Deletes a node that your Amazon Web Services account owns.
-
#get_accessor(params = {}) ⇒ Types::GetAccessorOutput
Returns detailed information about an accessor.
-
#get_member(params = {}) ⇒ Types::GetMemberOutput
Returns detailed information about a member.
-
#get_network(params = {}) ⇒ Types::GetNetworkOutput
Returns detailed information about a network.
-
#get_node(params = {}) ⇒ Types::GetNodeOutput
Returns detailed information about a node.
-
#get_proposal(params = {}) ⇒ Types::GetProposalOutput
Returns detailed information about a proposal.
-
#list_accessors(params = {}) ⇒ Types::ListAccessorsOutput
Returns a list of the accessors and their properties.
-
#list_invitations(params = {}) ⇒ Types::ListInvitationsOutput
Returns a list of all invitations for the current Amazon Web Services account.
-
#list_members(params = {}) ⇒ Types::ListMembersOutput
Returns a list of the members in a network and properties of their configurations.
-
#list_networks(params = {}) ⇒ Types::ListNetworksOutput
Returns information about the networks in which the current Amazon Web Services account participates.
-
#list_nodes(params = {}) ⇒ Types::ListNodesOutput
Returns information about the nodes within a network.
-
#list_proposal_votes(params = {}) ⇒ Types::ListProposalVotesOutput
Returns the list of votes for a specified proposal, including the value of each vote and the unique identifier of the member that cast the vote.
-
#list_proposals(params = {}) ⇒ Types::ListProposalsOutput
Returns a list of proposals for the network.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for the specified resource.
-
#reject_invitation(params = {}) ⇒ Struct
Rejects an invitation to join a network.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites the specified tags for the specified Amazon Managed Blockchain resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the Amazon Managed Blockchain resource.
-
#update_member(params = {}) ⇒ Struct
Updates a member configuration with new parameters.
-
#update_node(params = {}) ⇒ Struct
Updates a node configuration with new parameters.
-
#vote_on_proposal(params = {}) ⇒ Struct
Casts a vote for a specified ‘ProposalId` on behalf of a member.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2028 2029 2030 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 2028 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2031 2032 2033 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 2031 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 2001 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ManagedBlockchain') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-managedblockchain' context[:gem_version] = '1.86.0' Seahorse::Client::Request.new(handlers, context) end |
#create_accessor(params = {}) ⇒ Types::CreateAccessorOutput
Creates a new accessor for use with Amazon Managed Blockchain service that supports token based access. The accessor contains information required for token based access.
562 563 564 565 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 562 def create_accessor(params = {}, = {}) req = build_request(:create_accessor, params) req.send_request() end |
#create_member(params = {}) ⇒ Types::CreateMemberOutput
Creates a member within a Managed Blockchain network.
Applies only to Hyperledger Fabric.
634 635 636 637 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 634 def create_member(params = {}, = {}) req = build_request(:create_member, params) req.send_request() end |
#create_network(params = {}) ⇒ Types::CreateNetworkOutput
Creates a new blockchain network using Amazon Managed Blockchain.
Applies only to Hyperledger Fabric.
755 756 757 758 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 755 def create_network(params = {}, = {}) req = build_request(:create_network, params) req.send_request() end |
#create_node(params = {}) ⇒ Types::CreateNodeOutput
Creates a node on the specified blockchain network.
Applies to Hyperledger Fabric and Ethereum.
850 851 852 853 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 850 def create_node(params = {}, = {}) req = build_request(:create_node, params) req.send_request() end |
#create_proposal(params = {}) ⇒ Types::CreateProposalOutput
Creates a proposal for a change to the network that other members of the network can vote on, for example, a proposal to add a new member to the network. Any member can create a proposal.
Applies only to Hyperledger Fabric.
943 944 945 946 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 943 def create_proposal(params = {}, = {}) req = build_request(:create_proposal, params) req.send_request() end |
#delete_accessor(params = {}) ⇒ Struct
Deletes an accessor that your Amazon Web Services account owns. An accessor object is a container that has the information required for token based access to your Ethereum nodes including, the ‘BILLING_TOKEN`. After an accessor is deleted, the status of the accessor changes from `AVAILABLE` to `PENDING_DELETION`. An accessor in the `PENDING_DELETION` state can’t be used for new WebSocket requests or HTTP requests. However, WebSocket connections that were initiated while the accessor was in the `AVAILABLE` state remain open until they expire (up to 2 hours).
973 974 975 976 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 973 def delete_accessor(params = {}, = {}) req = build_request(:delete_accessor, params) req.send_request() end |
#delete_member(params = {}) ⇒ Struct
Deletes a member. Deleting a member removes the member and all associated resources from the network. ‘DeleteMember` can only be called for a specified `MemberId` if the principal performing the action is associated with the Amazon Web Services account that owns the member. In all other cases, the `DeleteMember` action is carried out as the result of an approved proposal to remove a member. If `MemberId` is the last member in a network specified by the last Amazon Web Services account, the network is deleted also.
Applies only to Hyperledger Fabric.
1008 1009 1010 1011 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1008 def delete_member(params = {}, = {}) req = build_request(:delete_member, params) req.send_request() end |
#delete_node(params = {}) ⇒ Struct
Deletes a node that your Amazon Web Services account owns. All data on the node is lost and cannot be recovered.
Applies to Hyperledger Fabric and Ethereum.
1050 1051 1052 1053 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1050 def delete_node(params = {}, = {}) req = build_request(:delete_node, params) req.send_request() end |
#get_accessor(params = {}) ⇒ Types::GetAccessorOutput
Returns detailed information about an accessor. An accessor object is a container that has the information required for token based access to your Ethereum nodes.
1088 1089 1090 1091 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1088 def get_accessor(params = {}, = {}) req = build_request(:get_accessor, params) req.send_request() end |
#get_member(params = {}) ⇒ Types::GetMemberOutput
Returns detailed information about a member.
Applies only to Hyperledger Fabric.
1134 1135 1136 1137 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1134 def get_member(params = {}, = {}) req = build_request(:get_member, params) req.send_request() end |
#get_network(params = {}) ⇒ Types::GetNetworkOutput
Returns detailed information about a network.
Applies to Hyperledger Fabric and Ethereum.
1180 1181 1182 1183 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1180 def get_network(params = {}, = {}) req = build_request(:get_network, params) req.send_request() end |
#get_node(params = {}) ⇒ Types::GetNodeOutput
Returns detailed information about a node.
Applies to Hyperledger Fabric and Ethereum.
1238 1239 1240 1241 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1238 def get_node(params = {}, = {}) req = build_request(:get_node, params) req.send_request() end |
#get_proposal(params = {}) ⇒ Types::GetProposalOutput
Returns detailed information about a proposal.
Applies only to Hyperledger Fabric.
1289 1290 1291 1292 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1289 def get_proposal(params = {}, = {}) req = build_request(:get_proposal, params) req.send_request() end |
#list_accessors(params = {}) ⇒ Types::ListAccessorsOutput
Returns a list of the accessors and their properties. Accessor objects are containers that have the information required for token based access to your Ethereum nodes.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1344 1345 1346 1347 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1344 def list_accessors(params = {}, = {}) req = build_request(:list_accessors, params) req.send_request() end |
#list_invitations(params = {}) ⇒ Types::ListInvitationsOutput
Returns a list of all invitations for the current Amazon Web Services account.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1397 1398 1399 1400 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1397 def list_invitations(params = {}, = {}) req = build_request(:list_invitations, params) req.send_request() end |
#list_members(params = {}) ⇒ Types::ListMembersOutput
Returns a list of the members in a network and properties of their configurations.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1464 1465 1466 1467 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1464 def list_members(params = {}, = {}) req = build_request(:list_members, params) req.send_request() end |
#list_networks(params = {}) ⇒ Types::ListNetworksOutput
Returns information about the networks in which the current Amazon Web Services account participates.
Applies to Hyperledger Fabric and Ethereum.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1528 1529 1530 1531 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1528 def list_networks(params = {}, = {}) req = build_request(:list_networks, params) req.send_request() end |
#list_nodes(params = {}) ⇒ Types::ListNodesOutput
Returns information about the nodes within a network.
Applies to Hyperledger Fabric and Ethereum.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1589 1590 1591 1592 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1589 def list_nodes(params = {}, = {}) req = build_request(:list_nodes, params) req.send_request() end |
#list_proposal_votes(params = {}) ⇒ Types::ListProposalVotesOutput
Returns the list of votes for a specified proposal, including the value of each vote and the unique identifier of the member that cast the vote.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1641 1642 1643 1644 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1641 def list_proposal_votes(params = {}, = {}) req = build_request(:list_proposal_votes, params) req.send_request() end |
#list_proposals(params = {}) ⇒ Types::ListProposalsOutput
Returns a list of proposals for the network.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1692 1693 1694 1695 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1692 def list_proposals(params = {}, = {}) req = build_request(:list_proposals, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for the specified resource. Each tag consists of a key and optional value.
For more information about tags, see [Tagging Resources] in the *Amazon Managed Blockchain Ethereum Developer Guide*, or [Tagging Resources] in the *Amazon Managed Blockchain Hyperledger Fabric Developer Guide*.
[1]: docs.aws.amazon.com/managed-blockchain/latest/ethereum-dev/tagging-resources.html [2]: docs.aws.amazon.com/managed-blockchain/latest/hyperledger-fabric-dev/tagging-resources.html
1738 1739 1740 1741 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1738 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#reject_invitation(params = {}) ⇒ Struct
Rejects an invitation to join a network. This action can be called by a principal in an Amazon Web Services account that has received an invitation to create a member and join a network.
Applies only to Hyperledger Fabric.
1764 1765 1766 1767 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1764 def reject_invitation(params = {}, = {}) req = build_request(:reject_invitation, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites the specified tags for the specified Amazon Managed Blockchain resource. Each tag consists of a key and optional value.
When you specify a tag key that already exists, the tag value is overwritten with the new value. Use ‘UntagResource` to remove tag keys.
A resource can have up to 50 tags. If you try to create more than 50 tags for a resource, your request fails and returns an error.
For more information about tags, see [Tagging Resources] in the *Amazon Managed Blockchain Ethereum Developer Guide*, or [Tagging Resources] in the *Amazon Managed Blockchain Hyperledger Fabric Developer Guide*.
[1]: docs.aws.amazon.com/managed-blockchain/latest/ethereum-dev/tagging-resources.html [2]: docs.aws.amazon.com/managed-blockchain/latest/hyperledger-fabric-dev/tagging-resources.html
1819 1820 1821 1822 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1819 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the Amazon Managed Blockchain resource.
For more information about tags, see [Tagging Resources] in the *Amazon Managed Blockchain Ethereum Developer Guide*, or [Tagging Resources] in the *Amazon Managed Blockchain Hyperledger Fabric Developer Guide*.
[1]: docs.aws.amazon.com/managed-blockchain/latest/ethereum-dev/tagging-resources.html [2]: docs.aws.amazon.com/managed-blockchain/latest/hyperledger-fabric-dev/tagging-resources.html
1862 1863 1864 1865 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1862 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_member(params = {}) ⇒ Struct
Updates a member configuration with new parameters.
Applies only to Hyperledger Fabric.
1903 1904 1905 1906 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1903 def update_member(params = {}, = {}) req = build_request(:update_member, params) req.send_request() end |
#update_node(params = {}) ⇒ Struct
Updates a node configuration with new parameters.
Applies only to Hyperledger Fabric.
1954 1955 1956 1957 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1954 def update_node(params = {}, = {}) req = build_request(:update_node, params) req.send_request() end |
#vote_on_proposal(params = {}) ⇒ Struct
Casts a vote for a specified ‘ProposalId` on behalf of a member. The member to vote as, specified by `VoterMemberId`, must be in the same Amazon Web Services account as the principal that calls the action.
Applies only to Hyperledger Fabric.
1992 1993 1994 1995 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1992 def vote_on_proposal(params = {}, = {}) req = build_request(:vote_on_proposal, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2021 2022 2023 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 2021 def waiter_names [] end |