Class: Aws::ManagedBlockchain::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ManagedBlockchain::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-managedblockchain/client.rb
Overview
An API client for ManagedBlockchain. To construct a client, you need to configure a :region and :credentials.
client = Aws::ManagedBlockchain::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_accessor(params = {}) ⇒ Types::CreateAccessorOutput
Creates a new accessor for use with Amazon Managed Blockchain service that supports token based access.
-
#create_member(params = {}) ⇒ Types::CreateMemberOutput
Creates a member within a Managed Blockchain network.
-
#create_network(params = {}) ⇒ Types::CreateNetworkOutput
Creates a new blockchain network using Amazon Managed Blockchain.
-
#create_node(params = {}) ⇒ Types::CreateNodeOutput
Creates a node on the specified blockchain network.
-
#create_proposal(params = {}) ⇒ Types::CreateProposalOutput
Creates a proposal for a change to the network that other members of the network can vote on, for example, a proposal to add a new member to the network.
-
#delete_accessor(params = {}) ⇒ Struct
Deletes an accessor that your Amazon Web Services account owns.
-
#delete_member(params = {}) ⇒ Struct
Deletes a member.
-
#delete_node(params = {}) ⇒ Struct
Deletes a node that your Amazon Web Services account owns.
-
#get_accessor(params = {}) ⇒ Types::GetAccessorOutput
Returns detailed information about an accessor.
-
#get_member(params = {}) ⇒ Types::GetMemberOutput
Returns detailed information about a member.
-
#get_network(params = {}) ⇒ Types::GetNetworkOutput
Returns detailed information about a network.
-
#get_node(params = {}) ⇒ Types::GetNodeOutput
Returns detailed information about a node.
-
#get_proposal(params = {}) ⇒ Types::GetProposalOutput
Returns detailed information about a proposal.
-
#list_accessors(params = {}) ⇒ Types::ListAccessorsOutput
Returns a list of the accessors and their properties.
-
#list_invitations(params = {}) ⇒ Types::ListInvitationsOutput
Returns a list of all invitations for the current Amazon Web Services account.
-
#list_members(params = {}) ⇒ Types::ListMembersOutput
Returns a list of the members in a network and properties of their configurations.
-
#list_networks(params = {}) ⇒ Types::ListNetworksOutput
Returns information about the networks in which the current Amazon Web Services account participates.
-
#list_nodes(params = {}) ⇒ Types::ListNodesOutput
Returns information about the nodes within a network.
-
#list_proposal_votes(params = {}) ⇒ Types::ListProposalVotesOutput
Returns the list of votes for a specified proposal, including the value of each vote and the unique identifier of the member that cast the vote.
-
#list_proposals(params = {}) ⇒ Types::ListProposalsOutput
Returns a list of proposals for the network.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for the specified resource.
-
#reject_invitation(params = {}) ⇒ Struct
Rejects an invitation to join a network.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites the specified tags for the specified Amazon Managed Blockchain resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the Amazon Managed Blockchain resource.
-
#update_member(params = {}) ⇒ Struct
Updates a member configuration with new parameters.
-
#update_node(params = {}) ⇒ Struct
Updates a node configuration with new parameters.
-
#vote_on_proposal(params = {}) ⇒ Struct
Casts a vote for a specified
ProposalIdon behalf of a member.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
385 386 387 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 385 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1934 1935 1936 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1934 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1937 1938 1939 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1937 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1912 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-managedblockchain' context[:gem_version] = '1.49.0' Seahorse::Client::Request.new(handlers, context) end |
#create_accessor(params = {}) ⇒ Types::CreateAccessorOutput
Creates a new accessor for use with Amazon Managed Blockchain service that supports token based access. The accessor contains information required for token based access.
473 474 475 476 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 473 def create_accessor(params = {}, = {}) req = build_request(:create_accessor, params) req.send_request() end |
#create_member(params = {}) ⇒ Types::CreateMemberOutput
Creates a member within a Managed Blockchain network.
Applies only to Hyperledger Fabric.
545 546 547 548 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 545 def create_member(params = {}, = {}) req = build_request(:create_member, params) req.send_request() end |
#create_network(params = {}) ⇒ Types::CreateNetworkOutput
Creates a new blockchain network using Amazon Managed Blockchain.
Applies only to Hyperledger Fabric.
666 667 668 669 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 666 def create_network(params = {}, = {}) req = build_request(:create_network, params) req.send_request() end |
#create_node(params = {}) ⇒ Types::CreateNodeOutput
Creates a node on the specified blockchain network.
Applies to Hyperledger Fabric and Ethereum.
761 762 763 764 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 761 def create_node(params = {}, = {}) req = build_request(:create_node, params) req.send_request() end |
#create_proposal(params = {}) ⇒ Types::CreateProposalOutput
Creates a proposal for a change to the network that other members of the network can vote on, for example, a proposal to add a new member to the network. Any member can create a proposal.
Applies only to Hyperledger Fabric.
854 855 856 857 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 854 def create_proposal(params = {}, = {}) req = build_request(:create_proposal, params) req.send_request() end |
#delete_accessor(params = {}) ⇒ Struct
Deletes an accessor that your Amazon Web Services account owns. An accessor object is a container that has the information required for token based access to your Ethereum nodes including, the BILLING_TOKEN. After an accessor is deleted, the status of the accessor changes from AVAILABLE to PENDING_DELETION. An accessor in the PENDING_DELETION state can’t be used for new WebSocket requests or HTTP requests. However, WebSocket connections that were initiated while the accessor was in the AVAILABLE state remain open until they expire (up to 2 hours).
884 885 886 887 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 884 def delete_accessor(params = {}, = {}) req = build_request(:delete_accessor, params) req.send_request() end |
#delete_member(params = {}) ⇒ Struct
Deletes a member. Deleting a member removes the member and all associated resources from the network. DeleteMember can only be called for a specified MemberId if the principal performing the action is associated with the Amazon Web Services account that owns the member. In all other cases, the DeleteMember action is carried out as the result of an approved proposal to remove a member. If MemberId is the last member in a network specified by the last Amazon Web Services account, the network is deleted also.
Applies only to Hyperledger Fabric.
919 920 921 922 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 919 def delete_member(params = {}, = {}) req = build_request(:delete_member, params) req.send_request() end |
#delete_node(params = {}) ⇒ Struct
Deletes a node that your Amazon Web Services account owns. All data on the node is lost and cannot be recovered.
Applies to Hyperledger Fabric and Ethereum.
961 962 963 964 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 961 def delete_node(params = {}, = {}) req = build_request(:delete_node, params) req.send_request() end |
#get_accessor(params = {}) ⇒ Types::GetAccessorOutput
Returns detailed information about an accessor. An accessor object is a container that has the information required for token based access to your Ethereum nodes.
999 1000 1001 1002 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 999 def get_accessor(params = {}, = {}) req = build_request(:get_accessor, params) req.send_request() end |
#get_member(params = {}) ⇒ Types::GetMemberOutput
Returns detailed information about a member.
Applies only to Hyperledger Fabric.
1045 1046 1047 1048 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1045 def get_member(params = {}, = {}) req = build_request(:get_member, params) req.send_request() end |
#get_network(params = {}) ⇒ Types::GetNetworkOutput
Returns detailed information about a network.
Applies to Hyperledger Fabric and Ethereum.
1091 1092 1093 1094 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1091 def get_network(params = {}, = {}) req = build_request(:get_network, params) req.send_request() end |
#get_node(params = {}) ⇒ Types::GetNodeOutput
Returns detailed information about a node.
Applies to Hyperledger Fabric and Ethereum.
1149 1150 1151 1152 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1149 def get_node(params = {}, = {}) req = build_request(:get_node, params) req.send_request() end |
#get_proposal(params = {}) ⇒ Types::GetProposalOutput
Returns detailed information about a proposal.
Applies only to Hyperledger Fabric.
1200 1201 1202 1203 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1200 def get_proposal(params = {}, = {}) req = build_request(:get_proposal, params) req.send_request() end |
#list_accessors(params = {}) ⇒ Types::ListAccessorsOutput
Returns a list of the accessors and their properties. Accessor objects are containers that have the information required for token based access to your Ethereum nodes.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1255 1256 1257 1258 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1255 def list_accessors(params = {}, = {}) req = build_request(:list_accessors, params) req.send_request() end |
#list_invitations(params = {}) ⇒ Types::ListInvitationsOutput
Returns a list of all invitations for the current Amazon Web Services account.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1308 1309 1310 1311 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1308 def list_invitations(params = {}, = {}) req = build_request(:list_invitations, params) req.send_request() end |
#list_members(params = {}) ⇒ Types::ListMembersOutput
Returns a list of the members in a network and properties of their configurations.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1375 1376 1377 1378 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1375 def list_members(params = {}, = {}) req = build_request(:list_members, params) req.send_request() end |
#list_networks(params = {}) ⇒ Types::ListNetworksOutput
Returns information about the networks in which the current Amazon Web Services account participates.
Applies to Hyperledger Fabric and Ethereum.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1439 1440 1441 1442 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1439 def list_networks(params = {}, = {}) req = build_request(:list_networks, params) req.send_request() end |
#list_nodes(params = {}) ⇒ Types::ListNodesOutput
Returns information about the nodes within a network.
Applies to Hyperledger Fabric and Ethereum.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1500 1501 1502 1503 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1500 def list_nodes(params = {}, = {}) req = build_request(:list_nodes, params) req.send_request() end |
#list_proposal_votes(params = {}) ⇒ Types::ListProposalVotesOutput
Returns the list of votes for a specified proposal, including the value of each vote and the unique identifier of the member that cast the vote.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1552 1553 1554 1555 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1552 def list_proposal_votes(params = {}, = {}) req = build_request(:list_proposal_votes, params) req.send_request() end |
#list_proposals(params = {}) ⇒ Types::ListProposalsOutput
Returns a list of proposals for the network.
Applies only to Hyperledger Fabric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1603 1604 1605 1606 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1603 def list_proposals(params = {}, = {}) req = build_request(:list_proposals, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for the specified resource. Each tag consists of a key and optional value.
For more information about tags, see [Tagging Resources] in the *Amazon Managed Blockchain Ethereum Developer Guide*, or [Tagging Resources] in the *Amazon Managed Blockchain Hyperledger Fabric Developer Guide*.
[1]: docs.aws.amazon.com/managed-blockchain/latest/ethereum-dev/tagging-resources.html [2]: docs.aws.amazon.com/managed-blockchain/latest/hyperledger-fabric-dev/tagging-resources.html
1649 1650 1651 1652 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1649 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#reject_invitation(params = {}) ⇒ Struct
Rejects an invitation to join a network. This action can be called by a principal in an Amazon Web Services account that has received an invitation to create a member and join a network.
Applies only to Hyperledger Fabric.
1675 1676 1677 1678 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1675 def reject_invitation(params = {}, = {}) req = build_request(:reject_invitation, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites the specified tags for the specified Amazon Managed Blockchain resource. Each tag consists of a key and optional value.
When you specify a tag key that already exists, the tag value is overwritten with the new value. Use UntagResource to remove tag keys.
A resource can have up to 50 tags. If you try to create more than 50 tags for a resource, your request fails and returns an error.
For more information about tags, see [Tagging Resources] in the *Amazon Managed Blockchain Ethereum Developer Guide*, or [Tagging Resources] in the *Amazon Managed Blockchain Hyperledger Fabric Developer Guide*.
[1]: docs.aws.amazon.com/managed-blockchain/latest/ethereum-dev/tagging-resources.html [2]: docs.aws.amazon.com/managed-blockchain/latest/hyperledger-fabric-dev/tagging-resources.html
1730 1731 1732 1733 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1730 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the Amazon Managed Blockchain resource.
For more information about tags, see [Tagging Resources] in the *Amazon Managed Blockchain Ethereum Developer Guide*, or [Tagging Resources] in the *Amazon Managed Blockchain Hyperledger Fabric Developer Guide*.
[1]: docs.aws.amazon.com/managed-blockchain/latest/ethereum-dev/tagging-resources.html [2]: docs.aws.amazon.com/managed-blockchain/latest/hyperledger-fabric-dev/tagging-resources.html
1773 1774 1775 1776 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1773 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_member(params = {}) ⇒ Struct
Updates a member configuration with new parameters.
Applies only to Hyperledger Fabric.
1814 1815 1816 1817 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1814 def update_member(params = {}, = {}) req = build_request(:update_member, params) req.send_request() end |
#update_node(params = {}) ⇒ Struct
Updates a node configuration with new parameters.
Applies only to Hyperledger Fabric.
1865 1866 1867 1868 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1865 def update_node(params = {}, = {}) req = build_request(:update_node, params) req.send_request() end |
#vote_on_proposal(params = {}) ⇒ Struct
Casts a vote for a specified ProposalId on behalf of a member. The member to vote as, specified by VoterMemberId, must be in the same Amazon Web Services account as the principal that calls the action.
Applies only to Hyperledger Fabric.
1903 1904 1905 1906 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1903 def vote_on_proposal(params = {}, = {}) req = build_request(:vote_on_proposal, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1927 1928 1929 |
# File 'lib/aws-sdk-managedblockchain/client.rb', line 1927 def waiter_names [] end |